@@ -45,8 +45,8 @@ int64_t gerfsx(
         lapack_error_if( std::abs(n_err_bnds) > std::numeric_limits<lapack_int>::max() );
         lapack_error_if( std::abs(nparams) > std::numeric_limits<lapack_int>::max() );
     }
-    char trans_ = op2char( trans );
-    char equed_ = equed2char( equed );
+    char trans_ = to_char( trans );
+    char equed_ = to_char( equed );
     lapack_int n_ = (lapack_int) n;
     lapack_int nrhs_ = (lapack_int) nrhs;
     lapack_int lda_ = (lapack_int) lda;
@@ -118,8 +118,8 @@ int64_t gerfsx(
         lapack_error_if( std::abs(n_err_bnds) > std::numeric_limits<lapack_int>::max() );
         lapack_error_if( std::abs(nparams) > std::numeric_limits<lapack_int>::max() );
     }
-    char trans_ = op2char( trans );
-    char equed_ = equed2char( equed );
+    char trans_ = to_char( trans );
+    char equed_ = to_char( equed );
     lapack_int n_ = (lapack_int) n;
     lapack_int nrhs_ = (lapack_int) nrhs;
     lapack_int lda_ = (lapack_int) lda;
@@ -191,8 +191,8 @@ int64_t gerfsx(
         lapack_error_if( std::abs(n_err_bnds) > std::numeric_limits<lapack_int>::max() );
         lapack_error_if( std::abs(nparams) > std::numeric_limits<lapack_int>::max() );
     }
-    char trans_ = op2char( trans );
-    char equed_ = equed2char( equed );
+    char trans_ = to_char( trans );
+    char equed_ = to_char( equed );
     lapack_int n_ = (lapack_int) n;
     lapack_int nrhs_ = (lapack_int) nrhs;
     lapack_int lda_ = (lapack_int) lda;
@@ -536,8 +536,8 @@ int64_t gerfsx(
         lapack_error_if( std::abs(n_err_bnds) > std::numeric_limits<lapack_int>::max() );
         lapack_error_if( std::abs(nparams) > std::numeric_limits<lapack_int>::max() );
     }
-    char trans_ = op2char( trans );
-    char equed_ = equed2char( equed );
+    char trans_ = to_char( trans );
+    char equed_ = to_char( equed );
     lapack_int n_ = (lapack_int) n;
     lapack_int nrhs_ = (lapack_int) nrhs;
     lapack_int lda_ = (lapack_int) lda;
