@@ -37,9 +37,9 @@ int64_t gesvdx(
         lapack_error_if( std::abs(ldu) > std::numeric_limits<lapack_int>::max() );
         lapack_error_if( std::abs(ldvt) > std::numeric_limits<lapack_int>::max() );
     }
-    char jobu_ = job2char( jobu );
-    char jobvt_ = job2char( jobvt );
-    char range_ = range2char( range );
+    char jobu_ = to_char( jobu );
+    char jobvt_ = to_char( jobvt );
+    char range_ = to_char( range );
     lapack_int m_ = (lapack_int) m;
     lapack_int n_ = (lapack_int) n;
     lapack_int lda_ = (lapack_int) lda;
@@ -108,9 +108,9 @@ int64_t gesvdx(
         lapack_error_if( std::abs(ldu) > std::numeric_limits<lapack_int>::max() );
         lapack_error_if( std::abs(ldvt) > std::numeric_limits<lapack_int>::max() );
     }
-    char jobu_ = job2char( jobu );
-    char jobvt_ = job2char( jobvt );
-    char range_ = range2char( range );
+    char jobu_ = to_char( jobu );
+    char jobvt_ = to_char( jobvt );
+    char range_ = to_char( range );
     lapack_int m_ = (lapack_int) m;
     lapack_int n_ = (lapack_int) n;
     lapack_int lda_ = (lapack_int) lda;
@@ -179,9 +179,9 @@ int64_t gesvdx(
         lapack_error_if( std::abs(ldu) > std::numeric_limits<lapack_int>::max() );
         lapack_error_if( std::abs(ldvt) > std::numeric_limits<lapack_int>::max() );
     }
-    char jobu_ = job2char( jobu );
-    char jobvt_ = job2char( jobvt );
-    char range_ = range2char( range );
+    char jobu_ = to_char( jobu );
+    char jobvt_ = to_char( jobvt );
+    char range_ = to_char( range );
     lapack_int m_ = (lapack_int) m;
     lapack_int n_ = (lapack_int) n;
     lapack_int lda_ = (lapack_int) lda;
@@ -384,9 +384,9 @@ int64_t gesvdx(
         lapack_error_if( std::abs(ldu) > std::numeric_limits<lapack_int>::max() );
         lapack_error_if( std::abs(ldvt) > std::numeric_limits<lapack_int>::max() );
     }
-    char jobu_ = job2char( jobu );
-    char jobvt_ = job2char( jobvt );
-    char range_ = range2char( range );
+    char jobu_ = to_char( jobu );
+    char jobvt_ = to_char( jobvt );
+    char range_ = to_char( range );
     lapack_int m_ = (lapack_int) m;
     lapack_int n_ = (lapack_int) n;
     lapack_int lda_ = (lapack_int) lda;
