@@ -29,8 +29,8 @@ int64_t ggbak(
         lapack_error_if( std::abs(m) > std::numeric_limits<lapack_int>::max() );
         lapack_error_if( std::abs(ldv) > std::numeric_limits<lapack_int>::max() );
     }
-    char balance_ = balance2char( balance );
-    char side_ = side2char( side );
+    char balance_ = to_char( balance );
+    char side_ = to_char( side );
     lapack_int n_ = (lapack_int) n;
     lapack_int ilo_ = (lapack_int) ilo;
     lapack_int ihi_ = (lapack_int) ihi;
@@ -65,8 +65,8 @@ int64_t ggbak(
         lapack_error_if( std::abs(m) > std::numeric_limits<lapack_int>::max() );
         lapack_error_if( std::abs(ldv) > std::numeric_limits<lapack_int>::max() );
     }
-    char balance_ = balance2char( balance );
-    char side_ = side2char( side );
+    char balance_ = to_char( balance );
+    char side_ = to_char( side );
     lapack_int n_ = (lapack_int) n;
     lapack_int ilo_ = (lapack_int) ilo;
     lapack_int ihi_ = (lapack_int) ihi;
@@ -101,8 +101,8 @@ int64_t ggbak(
         lapack_error_if( std::abs(m) > std::numeric_limits<lapack_int>::max() );
         lapack_error_if( std::abs(ldv) > std::numeric_limits<lapack_int>::max() );
     }
-    char balance_ = balance2char( balance );
-    char side_ = side2char( side );
+    char balance_ = to_char( balance );
+    char side_ = to_char( side );
     lapack_int n_ = (lapack_int) n;
     lapack_int ilo_ = (lapack_int) ilo;
     lapack_int ihi_ = (lapack_int) ihi;
@@ -137,8 +137,8 @@ int64_t ggbak(
         lapack_error_if( std::abs(m) > std::numeric_limits<lapack_int>::max() );
         lapack_error_if( std::abs(ldv) > std::numeric_limits<lapack_int>::max() );
     }
-    char balance_ = balance2char( balance );
-    char side_ = side2char( side );
+    char balance_ = to_char( balance );
+    char side_ = to_char( side );
     lapack_int n_ = (lapack_int) n;
     lapack_int ilo_ = (lapack_int) ilo;
     lapack_int ihi_ = (lapack_int) ihi;
