@@ -35,9 +35,9 @@ int64_t gges(
         lapack_error_if( std::abs(ldvsl) > std::numeric_limits<lapack_int>::max() );
         lapack_error_if( std::abs(ldvsr) > std::numeric_limits<lapack_int>::max() );
     }
-    char jobvsl_ = job2char( jobvsl );
-    char jobvsr_ = job2char( jobvsr );
-    char sort_ = sort2char( sort );
+    char jobvsl_ = to_char( jobvsl );
+    char jobvsr_ = to_char( jobvsr );
+    char sort_ = to_char( sort );
     lapack_int n_ = (lapack_int) n;
     lapack_int lda_ = (lapack_int) lda;
     lapack_int ldb_ = (lapack_int) ldb;
@@ -120,9 +120,9 @@ int64_t gges(
         lapack_error_if( std::abs(ldvsl) > std::numeric_limits<lapack_int>::max() );
         lapack_error_if( std::abs(ldvsr) > std::numeric_limits<lapack_int>::max() );
     }
-    char jobvsl_ = job2char( jobvsl );
-    char jobvsr_ = job2char( jobvsr );
-    char sort_ = sort2char( sort );
+    char jobvsl_ = to_char( jobvsl );
+    char jobvsr_ = to_char( jobvsr );
+    char sort_ = to_char( sort );
     lapack_int n_ = (lapack_int) n;
     lapack_int lda_ = (lapack_int) lda;
     lapack_int ldb_ = (lapack_int) ldb;
@@ -205,9 +205,9 @@ int64_t gges(
         lapack_error_if( std::abs(ldvsl) > std::numeric_limits<lapack_int>::max() );
         lapack_error_if( std::abs(ldvsr) > std::numeric_limits<lapack_int>::max() );
     }
-    char jobvsl_ = job2char( jobvsl );
-    char jobvsr_ = job2char( jobvsr );
-    char sort_ = sort2char( sort );
+    char jobvsl_ = to_char( jobvsl );
+    char jobvsr_ = to_char( jobvsr );
+    char sort_ = to_char( sort );
     lapack_int n_ = (lapack_int) n;
     lapack_int lda_ = (lapack_int) lda;
     lapack_int ldb_ = (lapack_int) ldb;
@@ -284,9 +284,9 @@ int64_t gges(
         lapack_error_if( std::abs(ldvsl) > std::numeric_limits<lapack_int>::max() );
         lapack_error_if( std::abs(ldvsr) > std::numeric_limits<lapack_int>::max() );
     }
-    char jobvsl_ = job2char( jobvsl );
-    char jobvsr_ = job2char( jobvsr );
-    char sort_ = sort2char( sort );
+    char jobvsl_ = to_char( jobvsl );
+    char jobvsr_ = to_char( jobvsr );
+    char sort_ = to_char( sort );
     lapack_int n_ = (lapack_int) n;
     lapack_int lda_ = (lapack_int) lda;
     lapack_int ldb_ = (lapack_int) ldb;
