@@ -37,10 +37,10 @@ int64_t ggesx(
         lapack_error_if( std::abs(ldvsl) > std::numeric_limits<lapack_int>::max() );
         lapack_error_if( std::abs(ldvsr) > std::numeric_limits<lapack_int>::max() );
     }
-    char jobvsl_ = job2char( jobvsl );
-    char jobvsr_ = job2char( jobvsr );
-    char sort_ = sort2char( sort );
-    char sense_ = sense2char( sense );
+    char jobvsl_ = to_char( jobvsl );
+    char jobvsr_ = to_char( jobvsr );
+    char sort_ = to_char( sort );
+    char sense_ = to_char( sense );
     lapack_int n_ = (lapack_int) n;
     lapack_int lda_ = (lapack_int) lda;
     lapack_int ldb_ = (lapack_int) ldb;
@@ -134,10 +134,10 @@ int64_t ggesx(
         lapack_error_if( std::abs(ldvsl) > std::numeric_limits<lapack_int>::max() );
         lapack_error_if( std::abs(ldvsr) > std::numeric_limits<lapack_int>::max() );
     }
-    char jobvsl_ = job2char( jobvsl );
-    char jobvsr_ = job2char( jobvsr );
-    char sort_ = sort2char( sort );
-    char sense_ = sense2char( sense );
+    char jobvsl_ = to_char( jobvsl );
+    char jobvsr_ = to_char( jobvsr );
+    char sort_ = to_char( sort );
+    char sense_ = to_char( sense );
     lapack_int n_ = (lapack_int) n;
     lapack_int lda_ = (lapack_int) lda;
     lapack_int ldb_ = (lapack_int) ldb;
@@ -231,10 +231,10 @@ int64_t ggesx(
         lapack_error_if( std::abs(ldvsl) > std::numeric_limits<lapack_int>::max() );
         lapack_error_if( std::abs(ldvsr) > std::numeric_limits<lapack_int>::max() );
     }
-    char jobvsl_ = job2char( jobvsl );
-    char jobvsr_ = job2char( jobvsr );
-    char sort_ = sort2char( sort );
-    char sense_ = sense2char( sense );
+    char jobvsl_ = to_char( jobvsl );
+    char jobvsr_ = to_char( jobvsr );
+    char sort_ = to_char( sort );
+    char sense_ = to_char( sense );
     lapack_int n_ = (lapack_int) n;
     lapack_int lda_ = (lapack_int) lda;
     lapack_int ldb_ = (lapack_int) ldb;
@@ -322,10 +322,10 @@ int64_t ggesx(
         lapack_error_if( std::abs(ldvsl) > std::numeric_limits<lapack_int>::max() );
         lapack_error_if( std::abs(ldvsr) > std::numeric_limits<lapack_int>::max() );
     }
-    char jobvsl_ = job2char( jobvsl );
-    char jobvsr_ = job2char( jobvsr );
-    char sort_ = sort2char( sort );
-    char sense_ = sense2char( sense );
+    char jobvsl_ = to_char( jobvsl );
+    char jobvsr_ = to_char( jobvsr );
+    char sort_ = to_char( sort );
+    char sense_ = to_char( sense );
     lapack_int n_ = (lapack_int) n;
     lapack_int lda_ = (lapack_int) lda;
     lapack_int ldb_ = (lapack_int) ldb;
