@@ -35,8 +35,8 @@ int64_t ggev3(
         lapack_error_if( std::abs(ldvl) > std::numeric_limits<lapack_int>::max() );
         lapack_error_if( std::abs(ldvr) > std::numeric_limits<lapack_int>::max() );
     }
-    char jobvl_ = job2char( jobvl );
-    char jobvr_ = job2char( jobvr );
+    char jobvl_ = to_char( jobvl );
+    char jobvr_ = to_char( jobvr );
     lapack_int n_ = (lapack_int) n;
     lapack_int lda_ = (lapack_int) lda;
     lapack_int ldb_ = (lapack_int) ldb;
@@ -107,8 +107,8 @@ int64_t ggev3(
         lapack_error_if( std::abs(ldvl) > std::numeric_limits<lapack_int>::max() );
         lapack_error_if( std::abs(ldvr) > std::numeric_limits<lapack_int>::max() );
     }
-    char jobvl_ = job2char( jobvl );
-    char jobvr_ = job2char( jobvr );
+    char jobvl_ = to_char( jobvl );
+    char jobvr_ = to_char( jobvr );
     lapack_int n_ = (lapack_int) n;
     lapack_int lda_ = (lapack_int) lda;
     lapack_int ldb_ = (lapack_int) ldb;
@@ -179,8 +179,8 @@ int64_t ggev3(
         lapack_error_if( std::abs(ldvl) > std::numeric_limits<lapack_int>::max() );
         lapack_error_if( std::abs(ldvr) > std::numeric_limits<lapack_int>::max() );
     }
-    char jobvl_ = job2char( jobvl );
-    char jobvr_ = job2char( jobvr );
+    char jobvl_ = to_char( jobvl );
+    char jobvr_ = to_char( jobvr );
     lapack_int n_ = (lapack_int) n;
     lapack_int lda_ = (lapack_int) lda;
     lapack_int ldb_ = (lapack_int) ldb;
@@ -247,8 +247,8 @@ int64_t ggev3(
         lapack_error_if( std::abs(ldvl) > std::numeric_limits<lapack_int>::max() );
         lapack_error_if( std::abs(ldvr) > std::numeric_limits<lapack_int>::max() );
     }
-    char jobvl_ = job2char( jobvl );
-    char jobvr_ = job2char( jobvr );
+    char jobvl_ = to_char( jobvl );
+    char jobvr_ = to_char( jobvr );
     lapack_int n_ = (lapack_int) n;
     lapack_int lda_ = (lapack_int) lda;
     lapack_int ldb_ = (lapack_int) ldb;
