@@ -41,9 +41,9 @@ int64_t ggsvd3(
         lapack_error_if( std::abs(ldv) > std::numeric_limits<lapack_int>::max() );
         lapack_error_if( std::abs(ldq) > std::numeric_limits<lapack_int>::max() );
     }
-    char jobu_ = jobu2char( jobu );
-    char jobv_ = job2char( jobv );
-    char jobq_ = jobq2char( jobq );
+    char jobu_ = to_char_jobu( jobu );
+    char jobv_ = to_char( jobv );
+    char jobq_ = to_char_jobq( jobq );
     lapack_int m_ = (lapack_int) m;
     lapack_int n_ = (lapack_int) n;
     lapack_int p_ = (lapack_int) p;
@@ -125,9 +125,9 @@ int64_t ggsvd3(
         lapack_error_if( std::abs(ldv) > std::numeric_limits<lapack_int>::max() );
         lapack_error_if( std::abs(ldq) > std::numeric_limits<lapack_int>::max() );
     }
-    char jobu_ = jobu2char( jobu );
-    char jobv_ = job2char( jobv );
-    char jobq_ = jobq2char( jobq );
+    char jobu_ = to_char_jobu( jobu );
+    char jobv_ = to_char( jobv );
+    char jobq_ = to_char_jobq( jobq );
     lapack_int m_ = (lapack_int) m;
     lapack_int n_ = (lapack_int) n;
     lapack_int p_ = (lapack_int) p;
@@ -209,9 +209,9 @@ int64_t ggsvd3(
         lapack_error_if( std::abs(ldv) > std::numeric_limits<lapack_int>::max() );
         lapack_error_if( std::abs(ldq) > std::numeric_limits<lapack_int>::max() );
     }
-    char jobu_ = jobu2char( jobu );
-    char jobv_ = job2char( jobv );
-    char jobq_ = jobq2char( jobq );
+    char jobu_ = to_char_jobu( jobu );
+    char jobv_ = to_char( jobv );
+    char jobq_ = to_char_jobq( jobq );
     lapack_int m_ = (lapack_int) m;
     lapack_int n_ = (lapack_int) n;
     lapack_int p_ = (lapack_int) p;
@@ -297,9 +297,9 @@ int64_t ggsvd3(
         lapack_error_if( std::abs(ldv) > std::numeric_limits<lapack_int>::max() );
         lapack_error_if( std::abs(ldq) > std::numeric_limits<lapack_int>::max() );
     }
-    char jobu_ = jobu2char( jobu );
-    char jobv_ = job2char( jobv );
-    char jobq_ = jobq2char( jobq );
+    char jobu_ = to_char_jobu( jobu );
+    char jobv_ = to_char( jobv );
+    char jobq_ = to_char_jobq( jobq );
     lapack_int m_ = (lapack_int) m;
     lapack_int n_ = (lapack_int) n;
     lapack_int p_ = (lapack_int) p;
