@@ -32,7 +32,7 @@ int64_t gttrs(
         lapack_error_if( std::abs(nrhs) > std::numeric_limits<lapack_int>::max() );
         lapack_error_if( std::abs(ldb) > std::numeric_limits<lapack_int>::max() );
     }
-    char trans_ = op2char( trans );
+    char trans_ = to_char( trans );
     lapack_int n_ = (lapack_int) n;
     lapack_int nrhs_ = (lapack_int) nrhs;
     #ifndef LAPACK_ILP64
@@ -77,7 +77,7 @@ int64_t gttrs(
         lapack_error_if( std::abs(nrhs) > std::numeric_limits<lapack_int>::max() );
         lapack_error_if( std::abs(ldb) > std::numeric_limits<lapack_int>::max() );
     }
-    char trans_ = op2char( trans );
+    char trans_ = to_char( trans );
     lapack_int n_ = (lapack_int) n;
     lapack_int nrhs_ = (lapack_int) nrhs;
     #ifndef LAPACK_ILP64
@@ -122,7 +122,7 @@ int64_t gttrs(
         lapack_error_if( std::abs(nrhs) > std::numeric_limits<lapack_int>::max() );
         lapack_error_if( std::abs(ldb) > std::numeric_limits<lapack_int>::max() );
     }
-    char trans_ = op2char( trans );
+    char trans_ = to_char( trans );
     lapack_int n_ = (lapack_int) n;
     lapack_int nrhs_ = (lapack_int) nrhs;
     #ifndef LAPACK_ILP64
@@ -232,7 +232,7 @@ int64_t gttrs(
         lapack_error_if( std::abs(nrhs) > std::numeric_limits<lapack_int>::max() );
         lapack_error_if( std::abs(ldb) > std::numeric_limits<lapack_int>::max() );
     }
-    char trans_ = op2char( trans );
+    char trans_ = to_char( trans );
     lapack_int n_ = (lapack_int) n;
     lapack_int nrhs_ = (lapack_int) nrhs;
     #ifndef LAPACK_ILP64
