@@ -30,8 +30,8 @@ int64_t hbtrd(
         lapack_error_if( std::abs(ldab) > std::numeric_limits<lapack_int>::max() );
         lapack_error_if( std::abs(ldq) > std::numeric_limits<lapack_int>::max() );
     }
-    char jobz_ = job2char( jobz );
-    char uplo_ = uplo2char( uplo );
+    char jobz_ = to_char( jobz );
+    char uplo_ = to_char( uplo );
     lapack_int n_ = (lapack_int) n;
     lapack_int kd_ = (lapack_int) kd;
     lapack_int ldab_ = (lapack_int) ldab;
@@ -70,8 +70,8 @@ int64_t hbtrd(
         lapack_error_if( std::abs(ldab) > std::numeric_limits<lapack_int>::max() );
         lapack_error_if( std::abs(ldq) > std::numeric_limits<lapack_int>::max() );
     }
-    char jobz_ = job2char( jobz );
-    char uplo_ = uplo2char( uplo );
+    char jobz_ = to_char( jobz );
+    char uplo_ = to_char( uplo );
     lapack_int n_ = (lapack_int) n;
     lapack_int kd_ = (lapack_int) kd;
     lapack_int ldab_ = (lapack_int) ldab;
