@@ -35,9 +35,9 @@ int64_t hgeqz(
         lapack_error_if( std::abs(ldq) > std::numeric_limits<lapack_int>::max() );
         lapack_error_if( std::abs(ldz) > std::numeric_limits<lapack_int>::max() );
     }
-    char jobschur_ = jobschur2char( jobschur );
-    char compq_ = job_comp2char( compq );
-    char compz_ = job_comp2char( compz );
+    char jobschur_ = to_char( jobschur );
+    char compq_ = to_char_comp( compq );
+    char compz_ = to_char_comp( compz );
     lapack_int n_ = (lapack_int) n;
     lapack_int ilo_ = (lapack_int) ilo;
     lapack_int ihi_ = (lapack_int) ihi;
@@ -114,9 +114,9 @@ int64_t hgeqz(
         lapack_error_if( std::abs(ldq) > std::numeric_limits<lapack_int>::max() );
         lapack_error_if( std::abs(ldz) > std::numeric_limits<lapack_int>::max() );
     }
-    char jobschur_ = jobschur2char( jobschur );
-    char compq_ = job_comp2char( compq );
-    char compz_ = job_comp2char( compz );
+    char jobschur_ = to_char( jobschur );
+    char compq_ = to_char_comp( compq );
+    char compz_ = to_char_comp( compz );
     lapack_int n_ = (lapack_int) n;
     lapack_int ilo_ = (lapack_int) ilo;
     lapack_int ihi_ = (lapack_int) ihi;
@@ -193,9 +193,9 @@ int64_t hgeqz(
         lapack_error_if( std::abs(ldq) > std::numeric_limits<lapack_int>::max() );
         lapack_error_if( std::abs(ldz) > std::numeric_limits<lapack_int>::max() );
     }
-    char jobschur_ = jobschur2char( jobschur );
-    char compq_ = job_comp2char( compq );
-    char compz_ = job_comp2char( compz );
+    char jobschur_ = to_char( jobschur );
+    char compq_ = to_char_comp( compq );
+    char compz_ = to_char_comp( compz );
     lapack_int n_ = (lapack_int) n;
     lapack_int ilo_ = (lapack_int) ilo;
     lapack_int ihi_ = (lapack_int) ihi;
@@ -266,9 +266,9 @@ int64_t hgeqz(
         lapack_error_if( std::abs(ldq) > std::numeric_limits<lapack_int>::max() );
         lapack_error_if( std::abs(ldz) > std::numeric_limits<lapack_int>::max() );
     }
-    char jobschur_ = jobschur2char( jobschur );
-    char compq_ = job_comp2char( compq );
-    char compz_ = job_comp2char( compz );
+    char jobschur_ = to_char( jobschur );
+    char compq_ = to_char_comp( compq );
+    char compz_ = to_char_comp( compz );
     lapack_int n_ = (lapack_int) n;
     lapack_int ilo_ = (lapack_int) ilo;
     lapack_int ihi_ = (lapack_int) ihi;
