@@ -27,8 +27,8 @@ float lanhb(
         lapack_error_if( std::abs(kd) > std::numeric_limits<lapack_int>::max() );
         lapack_error_if( std::abs(ldab) > std::numeric_limits<lapack_int>::max() );
     }
-    char norm_ = norm2char( norm );
-    char uplo_ = uplo2char( uplo );
+    char norm_ = to_char( norm );
+    char uplo_ = to_char( uplo );
     lapack_int n_ = (lapack_int) n;
     lapack_int kd_ = (lapack_int) kd;
     lapack_int ldab_ = (lapack_int) ldab;
@@ -101,8 +101,8 @@ double lanhb(
         lapack_error_if( std::abs(kd) > std::numeric_limits<lapack_int>::max() );
         lapack_error_if( std::abs(ldab) > std::numeric_limits<lapack_int>::max() );
     }
-    char norm_ = norm2char( norm );
-    char uplo_ = uplo2char( uplo );
+    char norm_ = to_char( norm );
+    char uplo_ = to_char( uplo );
     lapack_int n_ = (lapack_int) n;
     lapack_int kd_ = (lapack_int) kd;
     lapack_int ldab_ = (lapack_int) ldab;
