@@ -34,10 +34,10 @@ void larfb(
         lapack_error_if( std::abs(ldt) > std::numeric_limits<lapack_int>::max() );
         lapack_error_if( std::abs(ldc) > std::numeric_limits<lapack_int>::max() );
     }
-    char side_ = side2char( side );
-    char trans_ = op2char( trans );
-    char direction_ = direction2char( direction );
-    char storev_ = storev2char( storev );
+    char side_ = to_char( side );
+    char trans_ = to_char( trans );
+    char direction_ = to_char( direction );
+    char storev_ = to_char( storev );
     lapack_int m_ = (lapack_int) m;
     lapack_int n_ = (lapack_int) n;
     lapack_int k_ = (lapack_int) k;
@@ -78,10 +78,10 @@ void larfb(
         lapack_error_if( std::abs(ldt) > std::numeric_limits<lapack_int>::max() );
         lapack_error_if( std::abs(ldc) > std::numeric_limits<lapack_int>::max() );
     }
-    char side_ = side2char( side );
-    char trans_ = op2char( trans );
-    char direction_ = direction2char( direction );
-    char storev_ = storev2char( storev );
+    char side_ = to_char( side );
+    char trans_ = to_char( trans );
+    char direction_ = to_char( direction );
+    char storev_ = to_char( storev );
     lapack_int m_ = (lapack_int) m;
     lapack_int n_ = (lapack_int) n;
     lapack_int k_ = (lapack_int) k;
@@ -123,10 +123,10 @@ void larfb(
         lapack_error_if( std::abs(ldt) > std::numeric_limits<lapack_int>::max() );
         lapack_error_if( std::abs(ldc) > std::numeric_limits<lapack_int>::max() );
     }
-    char side_ = side2char( side );
-    char trans_ = op2char( trans );
-    char direction_ = direction2char( direction );
-    char storev_ = storev2char( storev );
+    char side_ = to_char( side );
+    char trans_ = to_char( trans );
+    char direction_ = to_char( direction );
+    char storev_ = to_char( storev );
     lapack_int m_ = (lapack_int) m;
     lapack_int n_ = (lapack_int) n;
     lapack_int k_ = (lapack_int) k;
@@ -264,10 +264,10 @@ void larfb(
         lapack_error_if( std::abs(ldt) > std::numeric_limits<lapack_int>::max() );
         lapack_error_if( std::abs(ldc) > std::numeric_limits<lapack_int>::max() );
     }
-    char side_ = side2char( side );
-    char trans_ = op2char( trans );
-    char direction_ = direction2char( direction );
-    char storev_ = storev2char( storev );
+    char side_ = to_char( side );
+    char trans_ = to_char( trans );
+    char direction_ = to_char( direction );
+    char storev_ = to_char( storev );
     lapack_int m_ = (lapack_int) m;
     lapack_int n_ = (lapack_int) n;
     lapack_int k_ = (lapack_int) k;
