@@ -40,6 +40,9 @@ int64_t orhr_col(
     lapack_int ldt_ = (lapack_int) ldt;
     lapack_int info_ = 0;
 
+    // Work around bug in LAPACK <= 3.12. See https://github.com/Reference-LAPACK/lapack/pull/1018
+    nb_ = min( nb_, n );
+
     LAPACK_sorhr_col(
         &m_, &n_, &nb_,
         A, &lda_,
@@ -159,6 +162,9 @@ int64_t orhr_col(
     lapack_int ldt_ = (lapack_int) ldt;
     lapack_int info_ = 0;
 
+    // Work around bug in LAPACK <= 3.12. See https://github.com/Reference-LAPACK/lapack/pull/1018
+    nb_ = min( nb_, n );
+
     LAPACK_dorhr_col(
         &m_, &n_, &nb_,
         A, &lda_,
