@@ -26,7 +26,7 @@ int64_t pbtrf(
         lapack_error_if( std::abs(kd) > std::numeric_limits<lapack_int>::max() );
         lapack_error_if( std::abs(ldab) > std::numeric_limits<lapack_int>::max() );
     }
-    char uplo_ = uplo2char( uplo );
+    char uplo_ = to_char( uplo );
     lapack_int n_ = (lapack_int) n;
     lapack_int kd_ = (lapack_int) kd;
     lapack_int ldab_ = (lapack_int) ldab;
@@ -54,7 +54,7 @@ int64_t pbtrf(
         lapack_error_if( std::abs(kd) > std::numeric_limits<lapack_int>::max() );
         lapack_error_if( std::abs(ldab) > std::numeric_limits<lapack_int>::max() );
     }
-    char uplo_ = uplo2char( uplo );
+    char uplo_ = to_char( uplo );
     lapack_int n_ = (lapack_int) n;
     lapack_int kd_ = (lapack_int) kd;
     lapack_int ldab_ = (lapack_int) ldab;
@@ -82,7 +82,7 @@ int64_t pbtrf(
         lapack_error_if( std::abs(kd) > std::numeric_limits<lapack_int>::max() );
         lapack_error_if( std::abs(ldab) > std::numeric_limits<lapack_int>::max() );
     }
-    char uplo_ = uplo2char( uplo );
+    char uplo_ = to_char( uplo );
     lapack_int n_ = (lapack_int) n;
     lapack_int kd_ = (lapack_int) kd;
     lapack_int ldab_ = (lapack_int) ldab;
@@ -176,7 +176,7 @@ int64_t pbtrf(
         lapack_error_if( std::abs(kd) > std::numeric_limits<lapack_int>::max() );
         lapack_error_if( std::abs(ldab) > std::numeric_limits<lapack_int>::max() );
     }
-    char uplo_ = uplo2char( uplo );
+    char uplo_ = to_char( uplo );
     lapack_int n_ = (lapack_int) n;
     lapack_int kd_ = (lapack_int) kd;
     lapack_int ldab_ = (lapack_int) ldab;
