@@ -38,9 +38,9 @@ int64_t posvx(
         lapack_error_if( std::abs(ldb) > std::numeric_limits<lapack_int>::max() );
         lapack_error_if( std::abs(ldx) > std::numeric_limits<lapack_int>::max() );
     }
-    char fact_ = factored2char( fact );
-    char uplo_ = uplo2char( uplo );
-    char equed_ = equed2char( *equed );
+    char fact_ = to_char( fact );
+    char uplo_ = to_char( uplo );
+    char equed_ = to_char( *equed );
     lapack_int n_ = (lapack_int) n;
     lapack_int nrhs_ = (lapack_int) nrhs;
     lapack_int lda_ = (lapack_int) lda;
@@ -69,7 +69,7 @@ int64_t posvx(
     if (info_ < 0) {
         throw Error();
     }
-    *equed = char2equed( equed_ );
+    from_string( std::string( 1, equed_ ), equed );
     return info_;
 }
 
@@ -96,9 +96,9 @@ int64_t posvx(
         lapack_error_if( std::abs(ldb) > std::numeric_limits<lapack_int>::max() );
         lapack_error_if( std::abs(ldx) > std::numeric_limits<lapack_int>::max() );
     }
-    char fact_ = factored2char( fact );
-    char uplo_ = uplo2char( uplo );
-    char equed_ = equed2char( *equed );
+    char fact_ = to_char( fact );
+    char uplo_ = to_char( uplo );
+    char equed_ = to_char( *equed );
     lapack_int n_ = (lapack_int) n;
     lapack_int nrhs_ = (lapack_int) nrhs;
     lapack_int lda_ = (lapack_int) lda;
@@ -127,7 +127,7 @@ int64_t posvx(
     if (info_ < 0) {
         throw Error();
     }
-    *equed = char2equed( equed_ );
+    from_string( std::string( 1, equed_ ), equed );
     return info_;
 }
 
@@ -154,9 +154,9 @@ int64_t posvx(
         lapack_error_if( std::abs(ldb) > std::numeric_limits<lapack_int>::max() );
         lapack_error_if( std::abs(ldx) > std::numeric_limits<lapack_int>::max() );
     }
-    char fact_ = factored2char( fact );
-    char uplo_ = uplo2char( uplo );
-    char equed_ = equed2char( *equed );
+    char fact_ = to_char( fact );
+    char uplo_ = to_char( uplo );
+    char equed_ = to_char( *equed );
     lapack_int n_ = (lapack_int) n;
     lapack_int nrhs_ = (lapack_int) nrhs;
     lapack_int lda_ = (lapack_int) lda;
@@ -185,7 +185,7 @@ int64_t posvx(
     if (info_ < 0) {
         throw Error();
     }
-    *equed = char2equed( equed_ );
+    from_string( std::string( 1, equed_ ), equed );
     return info_;
 }
 
@@ -381,9 +381,9 @@ int64_t posvx(
         lapack_error_if( std::abs(ldb) > std::numeric_limits<lapack_int>::max() );
         lapack_error_if( std::abs(ldx) > std::numeric_limits<lapack_int>::max() );
     }
-    char fact_ = factored2char( fact );
-    char uplo_ = uplo2char( uplo );
-    char equed_ = equed2char( *equed );
+    char fact_ = to_char( fact );
+    char uplo_ = to_char( uplo );
+    char equed_ = to_char( *equed );
     lapack_int n_ = (lapack_int) n;
     lapack_int nrhs_ = (lapack_int) nrhs;
     lapack_int lda_ = (lapack_int) lda;
@@ -412,7 +412,7 @@ int64_t posvx(
     if (info_ < 0) {
         throw Error();
     }
-    *equed = char2equed( equed_ );
+    from_string( std::string( 1, equed_ ), equed );
     return info_;
 }
 
