@@ -38,9 +38,9 @@ int64_t sbgvx(
         lapack_error_if( std::abs(iu) > std::numeric_limits<lapack_int>::max() );
         lapack_error_if( std::abs(ldz) > std::numeric_limits<lapack_int>::max() );
     }
-    char jobz_ = job2char( jobz );
-    char range_ = range2char( range );
-    char uplo_ = uplo2char( uplo );
+    char jobz_ = to_char( jobz );
+    char range_ = to_char( range );
+    char uplo_ = to_char( uplo );
     lapack_int n_ = (lapack_int) n;
     lapack_int ka_ = (lapack_int) ka;
     lapack_int kb_ = (lapack_int) kb;
@@ -110,9 +110,9 @@ int64_t sbgvx(
         lapack_error_if( std::abs(iu) > std::numeric_limits<lapack_int>::max() );
         lapack_error_if( std::abs(ldz) > std::numeric_limits<lapack_int>::max() );
     }
-    char jobz_ = job2char( jobz );
-    char range_ = range2char( range );
-    char uplo_ = uplo2char( uplo );
+    char jobz_ = to_char( jobz );
+    char range_ = to_char( range );
+    char uplo_ = to_char( uplo );
     lapack_int n_ = (lapack_int) n;
     lapack_int ka_ = (lapack_int) ka;
     lapack_int kb_ = (lapack_int) kb;
