@@ -27,7 +27,7 @@ int64_t stedc(
         lapack_error_if( std::abs(n) > std::numeric_limits<lapack_int>::max() );
         lapack_error_if( std::abs(ldz) > std::numeric_limits<lapack_int>::max() );
     }
-    char compz_ = job_comp2char( compz );
+    char compz_ = to_char_comp( compz );
     lapack_int n_ = (lapack_int) n;
     lapack_int ldz_ = (lapack_int) ldz;
     lapack_int info_ = 0;
@@ -80,7 +80,7 @@ int64_t stedc(
         lapack_error_if( std::abs(n) > std::numeric_limits<lapack_int>::max() );
         lapack_error_if( std::abs(ldz) > std::numeric_limits<lapack_int>::max() );
     }
-    char compz_ = job_comp2char( compz );
+    char compz_ = to_char_comp( compz );
     lapack_int n_ = (lapack_int) n;
     lapack_int ldz_ = (lapack_int) ldz;
     lapack_int info_ = 0;
@@ -133,7 +133,7 @@ int64_t stedc(
         lapack_error_if( std::abs(n) > std::numeric_limits<lapack_int>::max() );
         lapack_error_if( std::abs(ldz) > std::numeric_limits<lapack_int>::max() );
     }
-    char compz_ = job_comp2char( compz );
+    char compz_ = to_char_comp( compz );
     lapack_int n_ = (lapack_int) n;
     lapack_int ldz_ = (lapack_int) ldz;
     lapack_int info_ = 0;
@@ -191,7 +191,7 @@ int64_t stedc(
         lapack_error_if( std::abs(n) > std::numeric_limits<lapack_int>::max() );
         lapack_error_if( std::abs(ldz) > std::numeric_limits<lapack_int>::max() );
     }
-    char compz_ = job_comp2char( compz );
+    char compz_ = to_char_comp( compz );
     lapack_int n_ = (lapack_int) n;
     lapack_int ldz_ = (lapack_int) ldz;
     lapack_int info_ = 0;
