@@ -32,8 +32,8 @@ int64_t stevx(
         lapack_error_if( std::abs(iu) > std::numeric_limits<lapack_int>::max() );
         lapack_error_if( std::abs(ldz) > std::numeric_limits<lapack_int>::max() );
     }
-    char jobz_ = job2char( jobz );
-    char range_ = range2char( range );
+    char jobz_ = to_char( jobz );
+    char range_ = to_char( range );
     lapack_int n_ = (lapack_int) n;
     lapack_int il_ = (lapack_int) il;
     lapack_int iu_ = (lapack_int) iu;
@@ -91,8 +91,8 @@ int64_t stevx(
         lapack_error_if( std::abs(iu) > std::numeric_limits<lapack_int>::max() );
         lapack_error_if( std::abs(ldz) > std::numeric_limits<lapack_int>::max() );
     }
-    char jobz_ = job2char( jobz );
-    char range_ = range2char( range );
+    char jobz_ = to_char( jobz );
+    char range_ = to_char( range );
     lapack_int n_ = (lapack_int) n;
     lapack_int il_ = (lapack_int) il;
     lapack_int iu_ = (lapack_int) iu;
