@@ -36,9 +36,9 @@ int64_t sygvx(
         lapack_error_if( std::abs(ldz) > std::numeric_limits<lapack_int>::max() );
     }
     lapack_int itype_ = (lapack_int) itype;
-    char jobz_ = job2char( jobz );
-    char range_ = range2char( range );
-    char uplo_ = uplo2char( uplo );
+    char jobz_ = to_char( jobz );
+    char range_ = to_char( range );
+    char uplo_ = to_char( uplo );
     lapack_int n_ = (lapack_int) n;
     lapack_int lda_ = (lapack_int) lda;
     lapack_int ldb_ = (lapack_int) ldb;
@@ -121,9 +121,9 @@ int64_t sygvx(
         lapack_error_if( std::abs(ldz) > std::numeric_limits<lapack_int>::max() );
     }
     lapack_int itype_ = (lapack_int) itype;
-    char jobz_ = job2char( jobz );
-    char range_ = range2char( range );
-    char uplo_ = uplo2char( uplo );
+    char jobz_ = to_char( jobz );
+    char range_ = to_char( range );
+    char uplo_ = to_char( uplo );
     lapack_int n_ = (lapack_int) n;
     lapack_int lda_ = (lapack_int) lda;
     lapack_int ldb_ = (lapack_int) ldb;
