@@ -33,9 +33,9 @@ int64_t tbrfs(
         lapack_error_if( std::abs(ldb) > std::numeric_limits<lapack_int>::max() );
         lapack_error_if( std::abs(ldx) > std::numeric_limits<lapack_int>::max() );
     }
-    char uplo_ = uplo2char( uplo );
-    char trans_ = op2char( trans );
-    char diag_ = diag2char( diag );
+    char uplo_ = to_char( uplo );
+    char trans_ = to_char( trans );
+    char diag_ = to_char( diag );
     lapack_int n_ = (lapack_int) n;
     lapack_int kd_ = (lapack_int) kd;
     lapack_int nrhs_ = (lapack_int) nrhs;
@@ -82,9 +82,9 @@ int64_t tbrfs(
         lapack_error_if( std::abs(ldb) > std::numeric_limits<lapack_int>::max() );
         lapack_error_if( std::abs(ldx) > std::numeric_limits<lapack_int>::max() );
     }
-    char uplo_ = uplo2char( uplo );
-    char trans_ = op2char( trans );
-    char diag_ = diag2char( diag );
+    char uplo_ = to_char( uplo );
+    char trans_ = to_char( trans );
+    char diag_ = to_char( diag );
     lapack_int n_ = (lapack_int) n;
     lapack_int kd_ = (lapack_int) kd;
     lapack_int nrhs_ = (lapack_int) nrhs;
@@ -131,9 +131,9 @@ int64_t tbrfs(
         lapack_error_if( std::abs(ldb) > std::numeric_limits<lapack_int>::max() );
         lapack_error_if( std::abs(ldx) > std::numeric_limits<lapack_int>::max() );
     }
-    char uplo_ = uplo2char( uplo );
-    char trans_ = op2char( trans );
-    char diag_ = diag2char( diag );
+    char uplo_ = to_char( uplo );
+    char trans_ = to_char( trans );
+    char diag_ = to_char( diag );
     lapack_int n_ = (lapack_int) n;
     lapack_int kd_ = (lapack_int) kd;
     lapack_int nrhs_ = (lapack_int) nrhs;
@@ -180,9 +180,9 @@ int64_t tbrfs(
         lapack_error_if( std::abs(ldb) > std::numeric_limits<lapack_int>::max() );
         lapack_error_if( std::abs(ldx) > std::numeric_limits<lapack_int>::max() );
     }
-    char uplo_ = uplo2char( uplo );
-    char trans_ = op2char( trans );
-    char diag_ = diag2char( diag );
+    char uplo_ = to_char( uplo );
+    char trans_ = to_char( trans );
+    char diag_ = to_char( diag );
     lapack_int n_ = (lapack_int) n;
     lapack_int kd_ = (lapack_int) kd;
     lapack_int nrhs_ = (lapack_int) nrhs;
