@@ -24,8 +24,8 @@ int64_t trtri(
         lapack_error_if( std::abs(n) > std::numeric_limits<lapack_int>::max() );
         lapack_error_if( std::abs(lda) > std::numeric_limits<lapack_int>::max() );
     }
-    char uplo_ = uplo2char( uplo );
-    char diag_ = diag2char( diag );
+    char uplo_ = to_char( uplo );
+    char diag_ = to_char( diag );
     lapack_int n_ = (lapack_int) n;
     lapack_int lda_ = (lapack_int) lda;
     lapack_int info_ = 0;
@@ -50,8 +50,8 @@ int64_t trtri(
         lapack_error_if( std::abs(n) > std::numeric_limits<lapack_int>::max() );
         lapack_error_if( std::abs(lda) > std::numeric_limits<lapack_int>::max() );
     }
-    char uplo_ = uplo2char( uplo );
-    char diag_ = diag2char( diag );
+    char uplo_ = to_char( uplo );
+    char diag_ = to_char( diag );
     lapack_int n_ = (lapack_int) n;
     lapack_int lda_ = (lapack_int) lda;
     lapack_int info_ = 0;
@@ -76,8 +76,8 @@ int64_t trtri(
         lapack_error_if( std::abs(n) > std::numeric_limits<lapack_int>::max() );
         lapack_error_if( std::abs(lda) > std::numeric_limits<lapack_int>::max() );
     }
-    char uplo_ = uplo2char( uplo );
-    char diag_ = diag2char( diag );
+    char uplo_ = to_char( uplo );
+    char diag_ = to_char( diag );
     lapack_int n_ = (lapack_int) n;
     lapack_int lda_ = (lapack_int) lda;
     lapack_int info_ = 0;
@@ -102,8 +102,8 @@ int64_t trtri(
         lapack_error_if( std::abs(n) > std::numeric_limits<lapack_int>::max() );
         lapack_error_if( std::abs(lda) > std::numeric_limits<lapack_int>::max() );
     }
-    char uplo_ = uplo2char( uplo );
-    char diag_ = diag2char( diag );
+    char uplo_ = to_char( uplo );
+    char diag_ = to_char( diag );
     lapack_int n_ = (lapack_int) n;
     lapack_int lda_ = (lapack_int) lda;
     lapack_int info_ = 0;
