@@ -31,9 +31,9 @@ int64_t unmbr(
         lapack_error_if( std::abs(lda) > std::numeric_limits<lapack_int>::max() );
         lapack_error_if( std::abs(ldc) > std::numeric_limits<lapack_int>::max() );
     }
-    char vect_ = vect2char( vect );
-    char side_ = side2char( side );
-    char trans_ = op2char( trans );
+    char vect_ = to_char( vect );
+    char side_ = to_char( side );
+    char trans_ = to_char( trans );
     lapack_int m_ = (lapack_int) m;
     lapack_int n_ = (lapack_int) n;
     lapack_int k_ = (lapack_int) k;
@@ -180,9 +180,9 @@ int64_t unmbr(
         lapack_error_if( std::abs(lda) > std::numeric_limits<lapack_int>::max() );
         lapack_error_if( std::abs(ldc) > std::numeric_limits<lapack_int>::max() );
     }
-    char vect_ = vect2char( vect );
-    char side_ = side2char( side );
-    char trans_ = op2char( trans );
+    char vect_ = to_char( vect );
+    char side_ = to_char( side );
+    char trans_ = to_char( trans );
     lapack_int m_ = (lapack_int) m;
     lapack_int n_ = (lapack_int) n;
     lapack_int k_ = (lapack_int) k;
