@@ -29,9 +29,9 @@ int64_t upmtr(
         lapack_error_if( std::abs(n) > std::numeric_limits<lapack_int>::max() );
         lapack_error_if( std::abs(ldc) > std::numeric_limits<lapack_int>::max() );
     }
-    char side_ = side2char( side );
-    char uplo_ = uplo2char( uplo );
-    char trans_ = op2char( trans );
+    char side_ = to_char( side );
+    char uplo_ = to_char( uplo );
+    char trans_ = to_char( trans );
     lapack_int m_ = (lapack_int) m;
     lapack_int n_ = (lapack_int) n;
     lapack_int ldc_ = (lapack_int) ldc;
@@ -133,9 +133,9 @@ int64_t upmtr(
         lapack_error_if( std::abs(n) > std::numeric_limits<lapack_int>::max() );
         lapack_error_if( std::abs(ldc) > std::numeric_limits<lapack_int>::max() );
     }
-    char side_ = side2char( side );
-    char uplo_ = uplo2char( uplo );
-    char trans_ = op2char( trans );
+    char side_ = to_char( side );
+    char uplo_ = to_char( uplo );
+    char trans_ = to_char( trans );
     lapack_int m_ = (lapack_int) m;
     lapack_int n_ = (lapack_int) n;
     lapack_int ldc_ = (lapack_int) ldc;
